@@ -60,16 +60,21 @@ def calculate_parameter_factor(real_time_quotes_now):
     real_time_quotes_now['large_inflow_multiple'] = round(
         (real_time_quotes_now['large_order_net_inflow'] / real_time_quotes_now['reference_main_inflow']), 2)
 
-    real_time_quotes_now.loc[:, 'real_disk_diff_amount_exchange'] = round(
-        (real_time_quotes_now['disk_diff_amount_exchange'] / real_time_quotes_now['mv_circulation_ratio']), 2)
+    if 'real_disk_diff_amount_exchange' not in real_time_quotes_now.columns:
+        real_time_quotes_now.loc[:, 'real_disk_diff_amount_exchange'] = round(
+            (real_time_quotes_now['disk_diff_amount_exchange'] / real_time_quotes_now['mv_circulation_ratio']), 2)
 
-    real_time_quotes_now.loc[:, 'real_main_inflow_multiple'] = round(
-        (real_time_quotes_now['main_inflow_multiple'] / real_time_quotes_now['mv_circulation_ratio']), 2)
+    if 'real_main_inflow_multiple' not in real_time_quotes_now.columns:
+        real_time_quotes_now.loc[:, 'real_main_inflow_multiple'] = round(
+            (real_time_quotes_now['main_inflow_multiple'] / real_time_quotes_now['mv_circulation_ratio']), 2)
 
-    real_time_quotes_now.loc[:, 'real_super_main_inflow_multiple'] = round(
-        (real_time_quotes_now['super_main_inflow_multiple'] / real_time_quotes_now['mv_circulation_ratio']), 2)
-    real_time_quotes_now.loc[:, 'real_exchange'] = round(
-        (real_time_quotes_now['exchange'] / real_time_quotes_now['mv_circulation_ratio']), 2)
+    if 'real_super_main_inflow_multiple' not in real_time_quotes_now.columns:
+        real_time_quotes_now.loc[:, 'real_super_main_inflow_multiple'] = round(
+            (real_time_quotes_now['super_main_inflow_multiple'] / real_time_quotes_now['mv_circulation_ratio']), 2)
+
+    if 'real_exchange' not in real_time_quotes_now.columns:
+        real_time_quotes_now.loc[:, 'real_exchange'] = round(
+            (real_time_quotes_now['exchange'] / real_time_quotes_now['mv_circulation_ratio']), 2)
 
     real_time_quotes_now.loc[:, 'max_real_main_inflow_multiple'] = real_time_quotes_now[
         ['real_main_inflow_multiple', 'real_super_main_inflow_multiple']].max(axis=1)
