@@ -13,7 +13,9 @@ mongodb_util = MongodbUtil('27017')
 
 # 获取东方财富A股全部信息
 def get_a_stock_info():
-    return mongodb_util.find_all_data(extra_income_db_name.EM_A_STOCK_INFO)
+    em_a_stock_info = mongodb_util.find_all_data(extra_income_db_name.EM_A_STOCK_INFO)
+    em_a_stock_info = em_a_stock_info[~em_a_stock_info['symbol'].str.startswith(('8', '4'))]
+    return em_a_stock_info
 
 
 # 获取东方财富ETF全部信息
@@ -40,3 +42,7 @@ def get_us_etf_info():
 
 def get_hk_stock_info():
     return mongodb_util.find_all_data(extra_income_db_name.EM_HK_STOCK_INFO)
+
+
+if __name__ == '__main__':
+    get_a_stock_info()
\ No newline at end of file
