@@ -24,6 +24,9 @@ EM_US_STOCK_INFO = 'em_us_stock_info'
 # ip代理池
 IP_PROXY_POOL = 'ip_proxy_pool'
 
+# ip代理城市信息
+IP_PROXY_CITY_PROVINCE = 'ip_proxy_city_province'
+
 # 大单同步表
 BIG_DEAL_NAME = "ths_big_deal_fund"
 # 大单选择表
@@ -151,7 +154,6 @@ COMPANY_HOLDING_INFO = 'company_holding_info'
 #  公司业务组成
 COMPANY_BUSINESS_INFO = 'company_business_info'
 
-
 #  公司公告信息
 COMPANY_ANNOUNCE_INFO = 'company_announce_info'
 
